@@ -1,6 +1,7 @@
 //! Provides an interface and a default implementation of the `Clock` component
 
 use crate::types::Time;
+use chrono::Utc;
 
 /// Abstracts over the current time.
 pub trait Clock: Send + Sync {
@@ -13,6 +14,6 @@ pub trait Clock: Send + Sync {
 pub struct SystemClock;
 impl Clock for SystemClock {
     fn now(&self) -> Time {
-        Time::now()
+        Time(Utc::now())
     }
 }
